### 0.11.0 {small}`2024-12-19`

```{rubric} Features
```
* Adds support for Multi-GPU out-of-core support through Dask {pr}`179` {smaller}`S Dicks, I Gold & P Angerer`
* use `cuvs` over `raft` for `pp.neighbors` for `rapids>=24.12` {pr}`304` {smaller}`S Dicks`
* switched to a different implementation of `pp.harmony_integrate` based on `harmony-pytorch` {pr}`308` {smaller}`S Dicks`

```{rubric} Misc
```
* Update `get_random_state` for `scrublet` {pr}`301` {smaller}`S Dicks`
